==> libprotoident-2.0.12.tar.gz: libprotoident-2.0.12/lib/tcp/lpi_4d.cc <==
/*
 *
 * Copyright (c) 2011-2016 The University of Waikato, Hamilton, New Zealand.
 * All rights reserved.
 *
 * This file is part of libprotoident.
 *
 * This code has been developed by the University of Waikato WAND
 * research group. For further information please see http://www.wand.net.nz/
 *
 * libprotoident is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * libprotoident is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *
 */

#include <string.h>

#include "libprotoident.h"
#include "proto_manager.h"
#include "proto_common.h"

static inline bool match_4d_5f(uint32_t payload, uint32_t len) {

        if (len == 4 && MATCH(payload, 0x5d, 0x11, 0x00, 0x00))
                return true;
        return false;

}

static inline bool match_4d_other(uint32_t payload, uint32_t len) {

        if (len == 4 && MATCH(payload, 0x60, 0x11, 0x00, 0x00))
                return true;
        if (len == 4 && MATCH(payload, 0x61, 0x11, 0x00, 0x00))
                return true;
        return false;

}

static inline bool match_4d_len72(uint32_t payload, uint32_t len) {
        if (len == 72 && MATCH(payload, 0x00, 0x00, 0x00, 0x48))
                return true;
        return false;
}

static inline bool match_4d_len12(uint32_t payload, uint32_t len) {
        if (len == 12 && MATCH(payload, 0x00, 0x00, 0x00, 0x00))
                return true;
        return false;
}

static inline bool match_4d(lpi_data_t *data, lpi_module_t *mod UNUSED) {

        if (match_4d_5f(data->payload[0], data->payload_len[0])) {
                if (match_4d_other(data->payload[1], data->payload_len[1]))
                        return true;
        }

        if (match_4d_5f(data->payload[1], data->payload_len[1])) {
                if (match_4d_other(data->payload[0], data->payload_len[0]))
                        return true;
        }

        if (match_4d_len72(data->payload[0], data->payload_len[0])) {
                if (match_4d_len12(data->payload[1], data->payload_len[1]))
                        return true;
        }

        if (match_4d_len72(data->payload[1], data->payload_len[1])) {
                if (match_4d_len12(data->payload[0], data->payload_len[0]))
                        return true;
        }

	return false;
}

static lpi_module_t lpi_4d = {
	LPI_PROTO_4D,
	LPI_CATEGORY_DATABASES,
	"4D",
	75,
	match_4d
};

void register_4d(LPIModuleMap *mod_map) {
	register_protocol(&lpi_4d, mod_map);
}

==> libprotoident-2.0.15_p1.tar.gz: libprotoident-2.0.15-1/lib/tcp/lpi_4d.cc <==
/*
 *
 * Copyright (c) 2011-2016 The University of Waikato, Hamilton, New Zealand.
 * All rights reserved.
 *
 * This file is part of libprotoident.
 *
 * This code has been developed by the University of Waikato WAND
 * research group. For further information please see http://www.wand.net.nz/
 *
 * libprotoident is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * libprotoident is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *
 */

#include <string.h>

#include "libprotoident.h"
#include "proto_manager.h"
#include "proto_common.h"

static inline bool match_4d_5f(uint32_t payload, uint32_t len) {

        if (len == 4 && MATCH(payload, 0x5f, 0x11, 0x00, 0x00))
                return true;
        return false;

}

static inline bool match_4d_other(uint32_t payload, uint32_t len) {

        if (len == 4 && MATCH(payload, 0x60, 0x11, 0x00, 0x00))
                return true;
        if (len == 4 && MATCH(payload, 0x61, 0x11, 0x00, 0x00))
                return true;
        return false;

}

static inline bool match_4d_len72(uint32_t payload, uint32_t len) {
        if (len == 72 && MATCH(payload, 0x00, 0x00, 0x00, 0x48))
                return true;
        return false;
}

static inline bool match_4d_len12(uint32_t payload, uint32_t len) {
        if (len == 12 && MATCH(payload, 0x00, 0x00, 0x00, 0x00))
                return true;
        return false;
}

static inline bool match_4d(lpi_data_t *data, lpi_module_t *mod UNUSED) {

        if (match_4d_5f(data->payload[0], data->payload_len[0])) {
                if (match_4d_other(data->payload[1], data->payload_len[1]))
                        return true;
        }

        if (match_4d_5f(data->payload[1], data->payload_len[1])) {
                if (match_4d_other(data->payload[0], data->payload_len[0]))
                        return true;
        }

        if (match_4d_len72(data->payload[0], data->payload_len[0])) {
                if (match_4d_len12(data->payload[1], data->payload_len[1]))
                        return true;
        }

        if (match_4d_len72(data->payload[1], data->payload_len[1])) {
                if (match_4d_len12(data->payload[0], data->payload_len[0]))
                        return true;
        }

	return false;
}

static lpi_module_t lpi_4d = {
	LPI_PROTO_4D,
	LPI_CATEGORY_DATABASES,
	"4D",
	75,
	match_4d
};

void register_4d(LPIModuleMap *mod_map) {
	register_protocol(&lpi_4d, mod_map);
}
